AnnotationType enum
Annotation types matching PyMuPDF constants.
Values
- text → const AnnotationType
- link → const AnnotationType
- freeText → const AnnotationType
- line → const AnnotationType
- square → const AnnotationType
- circle → const AnnotationType
- polygon → const AnnotationType
- polyLine → const AnnotationType
- highlight → const AnnotationType
- underline → const AnnotationType
- squiggly → const AnnotationType
- strikeOut → const AnnotationType
- stamp → const AnnotationType
- caret → const AnnotationType
- ink → const AnnotationType
- popup → const AnnotationType
- fileAttachment → const AnnotationType
- sound → const AnnotationType
- movie → const AnnotationType
- widget → const AnnotationType
- screen → const AnnotationType
- printerMark → const AnnotationType
- trapNet → const AnnotationType
- watermark → const AnnotationType
- threeD → const AnnotationType
- redact → const AnnotationType
- unknown → const AnnotationType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AnnotationType> - A constant List of the values in this enum, in order of their declaration.