EmbeddedFile class

An embedded file within a PDF, equivalent to PyMuPDF's embedded file methods.

Constructors

EmbeddedFile({required String name, String? description, String? filename, String? ufilename, required Uint8List content, String? creationDate, String? modDate, required int size})
const

Properties

content Uint8List
File content.
final
creationDate String?
Creation date.
final
description String?
File description.
final
filename String?
Original filename.
final
hashCode int
The hash code for this object.
no setterinherited
modDate String?
Modification date.
final
name String
File name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Size of the uncompressed content.
final
ufilename String?
Unicode filename.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited