ExtractedImage class

Extracted image data.

Constructors

ExtractedImage({required int xref, required String ext, required int colorspace, required int width, required int height, required int bpc, required Uint8List image})
const

Properties

bpc int
Bits per component.
final
colorspace int
Colorspace components.
final
ext String
Image extension (e.g., "png", "jpeg").
final
hashCode int
The hash code for this object.
no setterinherited
height int
Image height.
final
image Uint8List
The raw image bytes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Size in bytes.
no setter
width int
Image width.
final
xref int
Cross-reference number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited