PdfArray class

PDF array.

Inheritance

Constructors

PdfArray([List<PdfObject>? items])

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
items List<PdfObject>
final
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(PdfObject item) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() String
Serialize this object to PDF syntax string.
inherited
toDoubleList() List<double>
Get as list of numbers.
toIntList() List<int>
Get as list of ints.
toPdfString() String
Serialize this object to PDF syntax bytes.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) PdfObject
operator []=(int index, PdfObject value) → void