PdfCrossRefTable class

Represents the cross-reference table of a PDF.

This tracks all indirect objects and their byte offsets.

Constructors

PdfCrossRefTable()

Properties

entries Map<int, CrossRefEntry>
Map of object number -> cross reference entry.
final
hashCode int
The hash code for this object.
no setterinherited
liveObjectNumbers List<int>
Get all live (in-use) object numbers.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Total number of objects.
no setter
trailer PdfDict
The trailer dictionary.
getter/setter pair

Methods

addEntry(int objectNumber, CrossRefEntry entry) → void
Add an entry.
getOffset(int objectNumber) int?
Get the offset for an object number.
merge(PdfCrossRefTable other) → void
Merge another cross-reference table (for incremental updates).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited