PdfIndirectObject class

An indirect object (objectNumber generation obj ... endobj).

Inheritance

Constructors

PdfIndirectObject(int objectNumber, int generation, PdfObject object)

Properties

dict PdfDict?
Get inner dict (from dict or stream).
no setter
generation int
final
hashCode int
The hash code for this object.
no setterinherited
isDict bool
If the inner object is a dict.
no setter
isStream bool
If the inner object is a stream.
no setter
object PdfObject
getter/setter pair
objectNumber int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamData Uint8List?
Get stream data (if stream).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() String
Serialize this object to PDF syntax string.
inherited
toPdfString() String
Serialize this object to PDF syntax bytes.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited