PdfMetadata class

PDF document metadata, equivalent to PyMuPDF's doc.metadata.

Constructors

PdfMetadata({String? title, String? author, String? subject, String? keywords, String? creator, String? producer, String? creationDate, String? modDate, String? format, String? encryption, bool trapped = false})
PdfMetadata.empty()
factory

Properties

author String?
getter/setter pair
creationDate String?
getter/setter pair
creator String?
getter/setter pair
encryption String?
getter/setter pair
format String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
keywords String?
getter/setter pair
modDate String?
getter/setter pair
producer String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String?
getter/setter pair
title String?
getter/setter pair
trapped bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, String?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited