PdfRef class

PDF indirect reference (e.g., "5 0 R").

Inheritance

Constructors

PdfRef(int objectNumber, [int generation = 0])

Properties

generation int
final
hashCode int
The hash code for this object.
no setteroverride
objectNumber int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() String
Serialize this object to PDF syntax string.
inherited
toPdfString() String
Serialize this object to PDF syntax bytes.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override