PdfStream class

A PDF stream (dictionary + binary data).

Inheritance

Constructors

PdfStream(PdfDict dict, Uint8List data)

Properties

data Uint8List
getter/setter pair
dict PdfDict
final
filters List<String>
Get the declared filter(s).
no setter
hashCode int
The hash code for this object.
no setterinherited
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() String
Serialize this object to PDF syntax string.
inherited
toPdfString() String
Serialize this object to PDF syntax bytes.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited