PdfStreamCodec class

PDF stream decompression and compression utilities.

Constructors

PdfStreamCodec()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Uint8List data, List<String> filters, {Map<String, dynamic>? decodeParms}) Uint8List
Decode (decompress) a PDF stream given its filter name(s).
encode(Uint8List data, String filter) Uint8List
Encode (compress) data with a filter.