PdfString class

PDF string (literal or hex).

Inheritance

Constructors

PdfString(String value, {bool isHex = false})
PdfString.fromBytes(Uint8List bytes)
Create from raw bytes.
factory

Properties

bytes Uint8List
Get raw bytes.
no setter
decoded String
Decode to Dart string, handling PDF encoding.
no setter
hashCode int
The hash code for this object.
no setterinherited
isHex bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() String
Serialize this object to PDF syntax string.
inherited
toPdfString() String
Serialize this object to PDF syntax bytes.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited