Point class

A 2D point, equivalent to PyMuPDF's fitz.Point.

Constructors

Point(double x, double y)
const
Point.fromList(List<num> list)
Create a Point from a list x, y.
factory

Properties

abs double
Distance from origin.
no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unit Point
Unit vector.
no setter
x double
final
y double
final

Methods

distanceTo(Point other) double
Euclidean distance to another point.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toList() List<double>
Convert to a list.
toString() String
A string representation of this object.
override
transform(dynamic matrix) Point
Transform this point using a Matrix.

Operators

operator *(double factor) Point
operator +(Point other) Point
operator -(Point other) Point
operator /(double factor) Point
operator ==(Object other) bool
The equality operator.
override
operator unary-() Point

Constants

zero → const Point
The zero point (origin).