TextBlock class

A text block extracted from a PDF page.

Equivalent to items returned by PyMuPDF's page.get_text("blocks").

Constructors

TextBlock({required double x0, required double y0, required double x1, required double y1, required String text, required int blockNumber, int blockType = 0})
const

Properties

blockNumber int
Block number (sequence index on page).
final
blockType int
Block type: 0 = text, 1 = image.
final
hashCode int
The hash code for this object.
no setterinherited
isImage bool
Whether this is an image block.
no setter
rect Rect
Bounding rectangle.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The text content of this block.
final
x0 double
Bounding box x0.
final
x1 double
Bounding box x1.
final
y0 double
Bounding box y0.
final
y1 double
Bounding box y1.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toList() List
Convert to tuple-like list as in PyMuPDF: (x0, y0, x1, y1, text, block_n, type).
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited