TextDictBlock class

A block within a TextDict.

Constructors

TextDictBlock({required int number, required int type, required Rect bbox, List<TextDictLine>? lines, int? imageWidth, int? imageHeight, String? imageColorspace, int? imageBpc, int? imageXref, int? imageSize})
const

Properties

bbox Rect
final
hashCode int
The hash code for this object.
no setterinherited
imageBpc int?
final
imageColorspace String?
final
imageHeight int?
final
imageSize int?
final
imageWidth int?
final
imageXref int?
final
isImage bool
no setter
lines List<TextDictLine>?
final
number int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited