TextDictLine class

A line within a TextDictBlock.

Constructors

TextDictLine({required Rect bbox, required Point2D wmode, required Point2D dir, required List<TextDictSpan> spans})
const

Properties

bbox Rect
final
dir Point2D
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spans List<TextDictSpan>
final
wmode Point2D
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited