TextWord class

A single word extracted from a PDF page with position info.

Equivalent to items returned by PyMuPDF's page.get_text("words").

Constructors

TextWord({required double x0, required double y0, required double x1, required double y1, required String word, required int blockNumber, required int lineNumber, required int wordNumber})
const

Properties

blockNumber int
Block number this word belongs to.
final
hashCode int
The hash code for this object.
no setterinherited
lineNumber int
Line number within the block.
final
rect Rect
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
word String
The word text.
final
wordNumber int
Word number within the line.
final
x0 double
final
x1 double
final
y0 double
final
y1 double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toList() List
Convert to list as in PyMuPDF: (x0, y0, x1, y1, word, block_n, line_n, word_n).
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited