Conv2d class

2D Convolution layer.

Applies a 2D convolution over an input image tensor. Input shape: (batch, inChannels, height, width) Output shape: (batch, outChannels, outH, outW)

Constructors

Conv2d(int inChannels, int outChannels, int kernelSize, {int stride = 1, int padding = 0, bool useBias = true})

Properties

bias Tensor?
Bias tensor (outChannels,).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inChannels int
final
kernelSize int
final
outChannels int
final
padding int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stride int
final
weight Tensor
Weight tensor (outChannels, inChannels, kernelSize, kernelSize).
getter/setter pair

Methods

forward(Tensor input) Tensor
Forward pass.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited