isReady property
bool
get
isReady
Whether the model has loaded weights and is ready for inference.
Implementation
bool get isReady => _isLoaded;
Whether the model has loaded weights and is ready for inference.
bool get isReady => _isLoaded;