DonutResult class
Result of a Donut inference pass.
Constructors
-
DonutResult({required List<
int> tokens, required String text, dynamic json}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- json → dynamic
-
The parsed JSON output (may be null if parsing fails).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The decoded text string.
final
-
tokens
→ List<
int> -
The raw generated token sequence.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited