FeedForward class

Position-wise feed-forward network: Linear → GELU → Linear

Constructors

FeedForward(int embedDim, int ffnDim)

Properties

activation GELU
final
fc1 Linear
getter/setter pair
fc2 Linear
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

forward(Tensor input) Tensor
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited