CrossRefEntry class
A single cross-reference entry.
Constructors
Properties
- generation → int
-
Generation number.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inUse → bool
-
Whether this object is in use (vs. free).
final
- isCompressed → bool
-
Whether this is a compressed object (in an object stream).
no setter
- objectStreamIndex → int?
-
For compressed objects: index within the object stream.
final
- objectStreamNumber → int?
-
For compressed objects: the object number of the object stream.
final
- offset → int
-
Byte offset in the file (for uncompressed objects).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited