IRect class
An integer rectangle, equivalent to PyMuPDF's fitz.IRect.
Properties
- area → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → int
-
no setter
- isEmpty → bool
-
no setter
- normalized → IRect
-
no setter
- rect → Rect
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
no setter
- x0 → int
-
final
- x1 → int
-
final
- y0 → int
-
final
- y1 → int
-
final
Methods
-
containsPoint(
int px, int py) → bool -
intersect(
IRect other) → IRect -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
overlaps(
IRect other) → bool -
toList(
) → List< int> -
toString(
) → String -
A string representation of this object.
override
-
union(
IRect other) → IRect
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override