Matrix class
A 3x3 transformation matrix (stored as a, b, c, d, e, f),
equivalent to PyMuPDF's fitz.Matrix.
The full matrix is:
| a b 0 |
| c d 0 |
| e f 1 |
Constructors
- Matrix(double a, double b, double c, double d, double e, double f)
-
const
-
Matrix.fromList(List<
num> list) -
Create from a list of 6 values.
factory
- Matrix.rotation(double degrees)
-
Create a rotation matrix (degrees).
factory
- Matrix.scale(double sx, double sy)
-
Create a scaling matrix.
factory
- Matrix.shear(double sx, double sy)
-
Create a shearing matrix.
factory
- Matrix.translation(double tx, double ty)
-
Create a translation matrix.
factory
Properties
- a → double
-
final
- b → double
-
final
- c → double
-
final
- d → double
-
final
- determinant → double
-
Determinant.
no setter
- e → double
-
final
- f → double
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inverse → Matrix
-
Inverse matrix.
no setter
- isInvertible → bool
-
Whether this matrix is invertible.
no setter
- isRectilinear → bool
-
Whether this is a rectilinear matrix (only scaling/translation/90° rotations).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
concat(
Matrix other) → Matrix - Concatenate (multiply) two matrices.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
preRotate(
double degrees) → Matrix - Pre-rotate this matrix.
-
preScale(
double sx, double sy) → Matrix - Pre-scale this matrix.
-
preTranslate(
double tx, double ty) → Matrix - Pre-translate this matrix.
-
toList(
) → List< double> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator *(
Matrix other) → Matrix -
operator ==(
Object other) → bool -
The equality operator.
override