PdfAnnotation class
A PDF annotation, equivalent to PyMuPDF's Annot class.
Constructors
-
PdfAnnotation({required AnnotationType type, required Rect rect, required int xref, String? content, String? title, String? subject, String? creationDate, String? modDate, List<
double> ? color, List<double> ? fillColor, double? borderWidth, double? opacity, int flags = 0, String? icon, String? lineEnding, List<Point> ? vertices, List<List< ? quadPoints, int? popupXref})double> > -
const
Properties
- borderWidth → double?
-
Border width.
final
-
color
→ List<
double> ? -
Color (as
r, g, bfloats 0..1).final - content → String?
-
Annotation content / text.
final
- creationDate → String?
-
Creation date.
final
-
fillColor
→ List<
double> ? -
Fill color for markup annotations.
final
- flags → int
-
Annotation flags.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
Icon name (for text, file attachment annotations).
final
- isPrintable → bool
-
Whether annotation is printable.
no setter
- isVisible → bool
-
Whether annotation is visible.
no setter
- lineEnding → String?
-
Line ending styles.
final
- modDate → String?
-
Modification date.
final
- opacity → double?
-
Opacity (0..1).
final
- popupXref → int?
-
Popup annotation xref.
final
-
quadPoints
→ List<
List< ?double> > -
Quadrilateral points (for highlight, underline, etc.).
final
- rect → Rect
-
Bounding rectangle.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → String?
-
Subject.
final
- title → String?
-
Title (author) of the annotation.
final
- type → AnnotationType
-
Annotation type.
final
- typeName → String
-
Type name string.
no setter
-
vertices
→ List<
Point> ? -
Vertices / points (for ink, polygon, polyline).
final
- xref → int
-
Cross-reference number.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited