LayerNorm class
Layer normalization over the last dimension.
Normalizes the input to zero mean and unit variance, then applies learnable affine transform: y = (x - mean) / sqrt(var + eps) * gamma + beta
Properties
- bias ↔ Tensor
-
Shift parameter (beta).
getter/setter pair
- eps → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- normalizedShape → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- weight ↔ Tensor
-
Scale parameter (gamma).
getter/setter pair
Methods
-
forward(
Tensor input) → Tensor - Forward pass.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited