SwinLayer class

A single Swin Transformer stage consisting of multiple blocks and an optional patch merging downsample layer.

Constructors

SwinLayer({required int dim, required int depth, required int numHeads, required int windowSize, bool downsample = true})

Properties

blocks List<SwinTransformerBlock>
getter/setter pair
depth int
final
dim int
final
downsample bool
final
hashCode int
The hash code for this object.
no setterinherited
numHeads int
final
patchMerging PatchMerging?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
windowSize int
final

Methods

forward(Tensor x, int h, int w) Tensor
Forward pass.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited